@@ -3,16 +3,14 @@ use Mojo::Base 'Mojolicious::Controller';
 
 our $VERSION = '0.02';
 
-use PPI  ();
-
 sub line_tokens {
     my $self = shift;
     my $line = $self->param('line') || '';
 
     my @tokens = ();
 
+    require PPI;
     my $doc = PPI::Document->new( \$line );
-
     my $doc_tokens = $doc->find('PPI::Token');
     require Params::Util;
     if ( Params::Util::_ARRAY0($doc_tokens) ) {
@@ -29,18 +27,25 @@ sub line_tokens {
                     $type = 'keyword';
                 }
                 else {
-                    $type = 'identifier';
+                    $type = 'variable';
                 }
             }
             elsif ( $token->isa('PPI::Token::Operator') ) {
-                $type = 'operator';
+                $type = 'keyword.operator';
             }
             elsif ( $token->isa('PPI::Token::Quote') ) {
                 $type = 'string';
             }
-            elsif ( $token->isa('PPI::Token::Comment') ) {
+            elsif ( $token->isa('PPI::Token::Comment') or $token->isa('PPI::Token::Pod')) {
                 $type = 'comment';
             }
+            elsif ( $token->isa('PPI::Token::Number') ) {
+                $type = 'constant.numeric';
+            }
+            elsif ( $token->isa('PPI::Token::Number') ) {
+                $type = 'constant.numeric';
+            }
+            
             push @tokens, { type => $type, value => $content };
         }
     }
